﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using SysComp = System.ComponentModel;

using DomainModel;
using IdeaBlade.EntityModel;

namespace WpfApplication1 {
  public class MainWindowViewModel : SysComp.INotifyPropertyChanged {

    #region Constructor
    public MainWindowViewModel() {
    }
    #endregion Constructor

    #region Methods

    public void Start() {
      FirstSample();
    }

    public void FirstSample() {
      StringBuilder aStringBuilder = new StringBuilder("Started FirstSample()...\n");

      var customersQuery =
        from cust in _mgr.Customers
        where cust.ContactTitle == "Sales Representative"
        orderby cust.CompanyName
        select cust;

      aStringBuilder.Append(string.Format("Retrieved {0} customers\n",
        customersQuery.ToList().Count));

      foreach (Customer aCustomer in customersQuery) {
        aStringBuilder.Append(string.Format("Customer: {0}\n", aCustomer.CompanyName));
      }

      Output = aStringBuilder.ToString();
    }

    #endregion Methods

    #region Data Bound Properties
    public string Output {
      get {
        return _output;
      }
      set {
        _output = value;
        RaisePropertyChanged("Output");
      }
    }
    #endregion Data Bound Properties

    #region INotifyPropertyChanged Implementation

    public event SysComp.PropertyChangedEventHandler PropertyChanged = delegate { };

    protected void RaisePropertyChanged(string propertyName) {
      PropertyChanged(this, new SysComp.PropertyChangedEventArgs(propertyName));
    }

    #endregion INotifyPropertyChanged Implementation

    #region Private Fields
    private NorthwindIBEntityManager _mgr = new NorthwindIBEntityManager();
    string _output = "";
    #endregion Private Fields

  }
}


